==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/uikit/UIEvent.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 2.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("UIKit") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/UIEvent/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class UIEventPtr extends Ptr<UIEvent, UIEventPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(UIEvent.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public UIEvent() {}
    protected UIEvent(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    /**
     * @since Available in iOS 3.0 and later.
     */
    @Property(selector = "type")
    public native UIEventType getType();
    /**
     * @since Available in iOS 3.0 and later.
     */
    @Property(selector = "subtype")
    public native UIEventSubtype getSubtype();
    @Property(selector = "timestamp")
    public native double getTimestamp();
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "allTouches")
    public native NSSet<UITouch> getAllTouches();
    @Method(selector = "touchesForWindow:")
    public native NSSet<UITouch> getTouches(UIWindow window);
    @Method(selector = "touchesForView:")
    public native NSSet<UITouch> getTouches(UIView view);
    /**
     * @since Available in iOS 3.2 and later.
     */
    @Method(selector = "touchesForGestureRecognizer:")
    public native NSSet<UITouch> getTouches(UIGestureRecognizer gesture);
    /**
     * @since Available in iOS 9.0 and later.
     */
    @Method(selector = "coalescedTouchesForTouch:")
    public native NSArray<UITouch> getCoalescedTouches(UITouch touch);
    /**
     * @since Available in iOS 9.0 and later.
     */
    @Method(selector = "predictedTouchesForTouch:")
    public native NSArray<UITouch> getPredictedTouches(UITouch touch);
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/uikit/UIEvent.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
import org.robovm.apple.cloudkit.*;
import org.robovm.apple.fileprovider.*;
import org.robovm.apple.intents.*;
import org.robovm.apple.usernotifications.*;
import org.robovm.apple.linkpresentation.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Library("UIKit") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/UIEvent/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class UIEventPtr extends Ptr<UIEvent, UIEventPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(UIEvent.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public UIEvent() {}
    protected UIEvent(Handle h, long handle) { super(h, handle); }
    protected UIEvent(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "type")
    public native UIEventType getType();
    @Property(selector = "subtype")
    public native UIEventSubtype getSubtype();
    @Property(selector = "timestamp")
    public native double getTimestamp();
    /**
     * @since Available in iOS 13.4 and later.
     */
    @Property(selector = "modifierFlags")
    public native UIKeyModifierFlags getModifierFlags();
    /**
     * @since Available in iOS 13.4 and later.
     */
    @Property(selector = "buttonMask")
    public native UIEventButtonMask getButtonMask();
    @Property(selector = "allTouches")
    public native NSSet<UITouch> getAllTouches();
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "touchesForWindow:")
    public native NSSet<UITouch> getTouches(UIWindow window);
    @Method(selector = "touchesForView:")
    public native NSSet<UITouch> getTouches(UIView view);
    @Method(selector = "touchesForGestureRecognizer:")
    public native NSSet<UITouch> getTouches(UIGestureRecognizer gesture);
    /**
     * @since Available in iOS 9.0 and later.
     */
    @Method(selector = "coalescedTouchesForTouch:")
    public native NSArray<UITouch> getCoalescedTouches(UITouch touch);
    /**
     * @since Available in iOS 9.0 and later.
     */
    @Method(selector = "predictedTouchesForTouch:")
    public native NSArray<UITouch> getPredictedTouches(UITouch touch);
    /*</methods>*/
}
